pyil-converter:
The better and easier way to convert the
format of a file.

Basic usage:
    For now, pyil only support text file, but
more will be added. Coded in UTF-8
to use, simply do:
>>>import pyil
>>>file=pyil.open('file type',C:\\example.txt','c:\\example_file without extension')
>>>file.what_ever()
>>>file.close()

If you have any suggestion, contact me at my email, G.Mpydev@gmail.com,
my site is https://wasted123.github.io/pyil/  :)
